// pages/personal/personal.js
const net = require("../../utils/net.js");
const {
  api_upload_file,
  api_user_update,
  api_upload_del,
} = require("../../utils/api.js");
const utils = require("../../utils/util.js");
Page({
  /**
   * 页面的初始数据
   */
  data: {
    userName: "",
    avatarUrl: "",
  },

  /**
   * 生命周期函数--监听页面加载
   */
  onLoad: function (options) {
    const userInfo = utils.getStorageSync("USERINFO");
    if (userInfo && userInfo.token) {
      this._userName = userInfo.userName;
      this.setData({
        userName: userInfo.userName,
        avatarUrl: userInfo.avatar,
      });
      this._oldImgUrl = userInfo.avatar;
    }
  },
  changeUserPhoto() {
    const _this = this;
    wx.showActionSheet({
      itemList: ["从相册中", "拍照"],
      success(res) {
        if (res.tapIndex == 0) {
          _this.chooseImage("album");
        } else {
          _this.chooseImage("camera");
        }
      },
      fail(res) {},
    });
  },

  chooseImage(type) {
    const _this = this;
    wx.chooseImage({
      count: 1,
      sizeType: ["original", "compressed"],
      sourceType: [type],
      success(res) {
        // tempFilePath可以作为img标签的src属性显示图片
        _this.setData({ avatarUrl: res.tempFilePaths[0] });
      },
    });
  },
  uploadImage(filePath) {
    let params = {};
    params.url = api_upload_file;
    params.filePath = filePath;
    params.data = {
      project: "daily",
      contentType: "daily/project",
    };
    net.uploadFile(params).then(
      (res) => {
        const { host, url } = res.data;
        if (Array.isArray(url) && url.length) {
          const imgSrc = host + url[0];
          this.deleteImage(this._oldImgUrl);
          this.data.avatarUrl = imgSrc;
          this.saveUserInfo();
        } else {
          wx.hideLoading();
        }
      },
      (err) => {
        wx.hideLoading();
      }
    );
  },

  inputChange(e) {
    const { value } = e.detail;
    this._userName = value;
  },

  deleteImage(imgUrl) {
    let params = {
      url: api_upload_del,
      data: {
        url: imgUrl,
        project: "daily/project",
      },
    };
    net.req(params, true).then();
  },

  tapSaveAction() {
    wx.showLoading({
      title: "正在保存中...",
    });
    const { avatarUrl } = this.data;
    if (avatarUrl != this._oldImgUrl) {
      this.uploadImage(avatarUrl);
    } else {
      this.saveUserInfo();
    }
  },

  saveUserInfo() {
    const { avatarUrl } = this.data;
    const params = {};
    params.data = {
      userName: this._userName,
      avatar: avatarUrl,
      hooid: "hooli_daily",
    };
    params.url = api_user_update;
    net
      .req(params)
      .then((data) => {
        if (data) {
          let userInfo = utils.getStorageSync("USERINFO");
          userInfo = Object.assign({}, userInfo, data.userInfo);
          utils.setStorageSync("USERINFO", userInfo);
          this.backToPage();
          wx.hideLoading();
        }
      })
      .catch(() => {
        wx.hideLoading();
      });
  },

  backToPage() {
    let pages = getCurrentPages(); /*在内存中的所有页面栈对象*/
    let reloadPage = pages[pages.length - 2]; /*我的页面对象*/
    reloadPage && reloadPage.refreshCallback && reloadPage.refreshCallback();
    // 获取用户信心成功返回
    wx.navigateBack();
  },
});
