// pages/history/history.js
const net = require("../../utils/net.js");
const utils = require("../../utils/util.js");
const { api_news_list, api_topic_type_list } = require("../../utils/api.js");
Page({
  /**
   * 页面的初始数据
   */
  data: {
    categoryList: [],
    listData: [],
    limit: 20,
    isEmpty: false,
    scrollH: 500,
    scrollTop: 0,
    isEnd: false,
  },

  /**
   * 生命周期函数--监听页面加载
   */
  onLoad: function () {
    this.loadCategoryListData();
  },

  getScrollH() {
    const _this = this;
    wx.createSelectorQuery()
      .select("#fixedTop")
      .boundingClientRect(function (res) {
        const sys = wx.getSystemInfoSync();
        _this.setData({
          scrollH: sys.screenHeight - res.height,
        });
      })
      .exec();
  },

  /**
   * 页面上拉触底事件的处理函数
   */
  scrollToLower() {
    if (this._isload) return false;
    this._isload = true;
    this.loadNewsData({
      isRefresh: false,
    });
  },

  loadCategoryListData() {
    let params = {};
    params.url = api_topic_type_list;
    params.data = { type: 2 };
    net.req(params, true).then(
      (data) => {
        this.setData(
          {
            categoryList: data,
          },
          () => {
            this._selectTab = 0;
            this.loadNewsData({ isRefresh: true });
            this.getScrollH();
          }
        );
      },
      (e) => {
        utils.showToast({ title: e.msg || "" });
      }
    );
  },
  loadNewsData(obj) {
    const { limit, listData, categoryList } = this.data;
    let params = {};
    params.url = api_news_list;
    params.data = {
      limit: limit,
      type: categoryList[this._selectTab].type,
    };
    const len = listData.length;
    if (!obj.isRefresh && len) {
      params.data.lastId = listData[len - 1].id;
    }
    net.req(params, true).then(
      (data) => {
        if (obj.isRefresh) {
          this.setData({
            scrollTop: 0,
            listData: data.list,
            isEmpty: !data.list.length,
            isEnd: data.list.length < limit,
          });
          this._refresh = false;
          this._isload = false;
        } else {
          if (data.list.length) {
            this.setData({
              listData: listData.concat(data.list),
              isEnd: data.list.length < limit,
            });
          }
          this._isload = data.list.length < limit;
        }
      },
      (e) => {
        obj.isRefresh ? (this._refresh = false) : (this._isload = false);
      }
    );
  },
  handleTabAction(e) {
    const { index, item } = e.detail;
    const { categoryList } = this.data;
    const newType = item.type;
    const oldType = categoryList[this._selectTab].type;
    if (newType != oldType) {
      this._selectTab = index;
      this._isload = false;
      this.loadNewsData({ isRefresh: true });
    }
  },
});
