//index.js
const net = require("../../utils/net.js");
const util = require("../../utils/util.js");
const { api_news_list, api_category_list } = require("../../utils/api.js");
Page({
  data: {
    newList: [],
    scrollH: 500,
    categoryList: [],
    limit: 20,
    categoryId: null,
    selectTab: 0,
    historyObj: {},
    scrollTop: 0,
    navBarH: 68,
    isRefresh: false,
    isEnd: false,
  },

  onLoad: function (options) {
    const { shareUid } = options;
    // 分享用户id
    if (shareUid && shareUid.length) {
      util.setStorageSync("SHAREUID", shareUid);
    }
    this.loadNewsData({ isRefresh: true });
    this.loadCategoryListData();
    this.getNavBarHeight();
    this.getStorageHistoryObj();
  },

  /**
   * 用户点击右上角分享
   */
  onShareAppMessage: function () {
    let path = `/pages/index/index`;
    const userInfo = util.getStorageSync("USERINFO");
    if (userInfo && userInfo.userCode && userInfo.userCode.length) {
      // 分享用户id
      path = path + "?shareUid=" + userInfo.userCode;
    }
    return {
      title: "留学daily",
      path: path,
    };
  },

  getScrollH() {
    const _this = this;
    wx.createSelectorQuery()
      .select("#fixedTop")
      .boundingClientRect(function (res) {
        const sys = wx.getSystemInfoSync();
        _this.setData({
          scrollH: sys.windowHeight - res.height,
        });
      })
      .exec();
  },

  getNavBarHeight: function () {
    const _this = this;
    var query = wx.createSelectorQuery();
    query.select(".nav-bar").boundingClientRect();
    query.exec(function (res) {
      res[0] &&
        res[0].height &&
        _this.setData({
          navBarH: res[0].height,
        });
    });
  },

  loadCategoryListData() {
    let params = {};
    params.url = api_category_list;
    params.data = {};
    net.req(params, true).then(
      (data) => {
        this.setData(
          {
            categoryList: data,
          },
          () => {
            this.getScrollH();
          }
        );
        this.data.categoryId = data[0].id;
      },
      (e) => {
        util.showToast({ title: e.msg || "" });
      }
    );
  },

  handleTabAction(e) {
    const { index } = e.detail;
    const { categoryId } = this.data;
    const selectCategoryId = this.data.categoryList[index].id;
    if (selectCategoryId != categoryId) {
      this.data.categoryId = selectCategoryId;
      this.setData({
        selectTab: index,
        scrollTop: 0,
      });
      // if (!newList[index] || !newList[index].length) {
      this.loadNewsData({ isRefresh: true });
      // }
    }
  },

  getStorageHistoryObj() {
    // 在组件实例进入页面节点树时执行
    let historyObj = wx.getStorageSync("LOOKHISTORY");
    try {
      historyObj = JSON.parse(historyObj);
    } catch (error) {
      historyObj = {};
    } finally {
      this.setData({
        historyObj: historyObj,
      });
    }
  },

  loadNewsData(obj) {
    const { limit, newList, categoryId, selectTab } = this.data;
    let params = {};
    params.url = api_news_list;
    params.data = {
      limit: limit,
    };
    const list = newList[selectTab] || [];
    const len = list.length;
    categoryId && (params.data.categoryId = categoryId);
    if (!obj.isRefresh && len) {
      params.data.lastId = list[len - 1].id;
    }

    net.req(params, true).then(
      (data) => {
        if (obj.isRefresh) {
          this.setData(
            {
              [`newList[${selectTab}]`]: data.list,
              isEnd: data.list.length < limit,
            },
            () => {
              this.setData({
                isRefresh: false,
              });
            }
          );
          this._refresh = false;
          this._isload = false;
        } else {
          if (data.list.length) {
            this.setData({
              [`newList[${selectTab}]`]: newList[selectTab].concat(data.list),
              isEnd: data.list.length < limit,
            });
          }
          this._isload = data.list.length < limit;
        }
      },
      (e) => {
        if (obj.isRefresh) {
          this.setData({
            isLoading: false,
          });
          this._refresh = false;
        } else {
          this._isload = false;
        }
      }
    );
  },

  refresherrefresh() {
    if (this._refresh) return;
    this.setData({
      isRefresh: true,
    });
    this.loadNewsData({ isRefresh: true });
  },
  /**
   * scroll-view上拉触底事件的处理函数
   */
  scrollToLower() {
    if (this._isload) return;
    this._isload = true;
    this.loadNewsData({ isRefresh: false });
  },
});
