const net = require("../../utils/net.js");
const util = require("../../utils/util.js");
const { api_wx_login, api_user_update } = require("../../utils/api.js");
Page({
  /**
   * 页面的初始数据
   */
  data: {
    showAuth: false,
  },

  pageData: {
    wxCode: "",
  },

  /**
   * 生命周期函数--监听页面加载
   */
  onLoad: function (options) {
    this._getWXCode();
  },

  _getWXCode: function (next) {
    const _this = this;
    wx.login({
      success: (res) => {
        _this.pageData.wxCode = res.code;
        next && next(res.code);
      },
    });
  },

  _tapPhoneLoginAction: function () {
    const _this = this;
    wx.navigateTo({
      url: "/pages/loginMobile/loginMobile",
      events: {
        // 为指定事件添加一个监听器，获取被打开页面传送到当前页面的数据
        loginMobileFromOpenedPage: function (data) {
          _this.navigateBack(data);
        },
      },
    });
  },

  _wxLogin(code, encryptedData, iv) {
    let params = {};
    params.url = api_wx_login;
    params.data = {
      code,
      encryptedData,
      iv,
      hooid: "hooli_daily",
    };
    const shareUid = util.getStorageSync("SHAREUID");
    if (shareUid && shareUid.length) {
      // 分享用户id
      params.data.shareUid = shareUid;
    }
    net.req(params, true).then(
      (data) => {
        if (data && data.userInfo && data.userInfo.token) {
          util.setStorageSync("USERINFO", data.userInfo);
          if (parseInt(data.newUser) == 1) {
            // 1为新用户、0为旧用户,去拿用户信息
            this.setData({
              showAuth: true,
            });
          } else {
            // 登录成功返回
            this.backToPage();
          }
          return false;
        } else {
          this._tapPhoneLoginAction();
        }
        util.hideLoading();
      },
      (e) => {
        this._tapPhoneLoginAction();
        util.hideLoading();
        util.showModal({
          title: "提示",
          content: e && e.msg,
          showCancel: false,
        });
      }
    );
  },

  _onGotUserInfo(e) {
    let { encryptedData, iv, rawData, signature } = e.detail;
    if (
      iv &&
      iv.length &&
      signature &&
      signature.length &&
      encryptedData &&
      encryptedData.length
    ) {
      try {
        rawData = JSON.parse(rawData);
      } catch (error) {
        rawData = rawData;
      }
      let params = {};
      params.data = {
        signature,
        encryptedData,
        iv,
        userName: rawData.nickName,
        avatar: rawData.avatarUrl,
        hooid: "hooli_daily",
      };
      params.url = api_user_update;
      net.req(params).then((data) => {
        if (data) {
          let userInfo = util.getStorageSync("USERINFO");
          userInfo = Object.assign({}, userInfo, data);
          util.setStorageSync("USERINFO", userInfo);
          this.backToPage();
        } else {
          this._tapPhoneLoginAction();
        }
      });
    } else {
      this._tapPhoneLoginAction();
    }
    this.setData({
      showAuth: false,
    });
  },

  backToPage() {
    let pages = getCurrentPages(); /*在内存中的所有页面栈对象*/
    let reloadPage = pages[pages.length - 2]; /*我的页面对象*/
    reloadPage && reloadPage.refreshCallback && reloadPage.refreshCallback();
    // 获取用户信心成功返回
    wx.navigateBack();
  },

  _tapNoLoginAction() {
    wx.navigateBack();
  },

  _getPhoneNumber(e) {
    let { encryptedData, iv } = e.detail;
    if (!encryptedData || !iv) {
      this._tapPhoneLoginAction();
      return false;
    } else {
      const { wxCode } = this.pageData;
      this.pageData.phoneNumberObj = e.detail;
      this._wxLogin(wxCode, encryptedData, iv);
    }
  },
});
