// pages/myAttention/myAttention.js
const net = require("../../utils/net.js");
const util = require("../../utils/util.js");
const {
  api_user_attention_list,
  api_topic_attention_list,
} = require("../../utils/api.js");
Page({
  /**
   * 页面的初始数据
   */
  data: {
    categoryList: [
      {
        type: 1,
        categoryName: "用户",
      },
      {
        type: 2,
        categoryName: "话题",
      },
    ],
    selectTab: 0,
    selectIndex: null,
    isEmpty: false,
    listData: [],
    limit: 20,
    scrollH: 500,
    scrollTop: 0,
    isEnd: false,
  },

  /**
   * 生命周期函数--监听页面加载
   */
  onLoad: function (options) {
    if (options && options.userId) {
      this._userId = options.userId;
      this.loadListData({ isRefresh: true });
    } else {
      util.showToast({ title: "用户信息错误,请您稍后再试!" });
    }
    this.getScrollH();
  },

  getScrollH() {
    const _this = this;
    wx.createSelectorQuery()
      .select("#fixedTop")
      .boundingClientRect(function (res) {
        const sys = wx.getSystemInfoSync();
        _this.setData({
          scrollH: sys.screenHeight - res.height,
        });
      })
      .exec();
  },
  /**
   * 页面上拉触底事件的处理函数
   */
  scrollToLower() {
    if (this._isload) return false;
    this._isload = true;
    this.loadListData({
      isRefresh: false,
    });
  },

  loadListData(obj) {
    const { limit, listData, categoryList, selectTab } = this.data;
    let params = {};
    params.url =
      categoryList[selectTab].type == 1
        ? api_user_attention_list
        : api_topic_attention_list;
    params.data = {
      limit: limit,
      userId: this._userId,
    };
    const len = listData.length;
    if (!obj.isRefresh && len) {
      params.data.lastId = listData[len - 1].id;
    }
    net.req(params, true).then(
      (data) => {
        if (obj.isRefresh) {
          this.setData({
            scrollTop: 0,
            listData: data.list,
            isEmpty: !data.list.length,
            isEnd: data.list.length < limit,
          });
          this._refresh = false;
          this._isload = false;
        } else {
          if (data.list.length) {
            this.setData({
              listData: listData.concat(data.list),
              isEnd: data.list.length < limit,
            });
            this._isload = data.list.length < limit;
          }
        }
      },
      (e) => {
        util.showToast({ title: e.msg || "" });
        obj.isRefresh ? (this._refresh = false) : (this._isload = false);
      }
    );
  },
  handleTabAction(e) {
    const { index, item } = e.detail;
    const { categoryList, selectTab } = this.data;
    const newType = item.type;
    const oldType = categoryList[selectTab].type;
    if (newType != oldType) {
      this.setData({
        selectTab: index,
        isEmpty: false,
      });
      this.loadListData({ isRefresh: true });
    }
  },

  tapUserAction(e) {
    const { item, index } = e.currentTarget.dataset;
    this._selectIndex = index;
    wx.navigateTo({
      url: `/pages/personal/personal?userId=${item.id}`,
    });
  },

  tapTagAction(e) {
    const { item, index } = e.currentTarget.dataset;
    this._selectIndex = index;
    wx.navigateTo({
      url: `/pages/tagDetail/tagDetail?tagId=${item.id}`,
    });
  },

  tapAttentionAction(e) {
    let pages = getCurrentPages(); /*在内存中的所有页面栈对象*/
    let reloadPage = pages[pages.length - 2]; /*我的页面对象*/
    reloadPage && reloadPage.refreshCallback && reloadPage.refreshCallback();
  },

  cancelAttention() {
    const { listData } = this.data;
    listData.splice(this._selectIndex, 1);
    this.setData({
      listData: listData,
      isEmpty: !listData.length,
    });
  },
});
