const util = {
  getStorageSync: (key) => {
    /*由于wx.getStorageSync有一定概率取不到值，若取不到再取一次*/
    try {
      let value = wx.getStorageSync(key);
      if (!value) {
        value = wx.getStorageSync(key);
      }
      return value;
    } catch (e) {
      return null;
    }
  },
  setStorageSync: (key, obj) => {
    /*wx.setStorageSync*/
    if (key && obj) {
      try {
        wx.setStorageSync(key, obj);
      } catch (e) {
        // Do something when catch error
      }
    }
  },
  removeStorageSync: (key) => {
    /*wx.removeStorageSync*/
    if (key) {
      try {
        wx.removeStorageSync(key);
      } catch (e) {
        // Do something when catch error
      }
    }
  },
  clearStorageSync: () => {
    /*wx.clearStorageSync*/
    try {
      wx.clearStorageSync();
    } catch (e) {
      // Do something when catch error
    }
  },
  showToast: (obj) => {
    /*wx.showToast*/
    try {
      wx.showToast({
        title: obj.title || "",
        icon: obj.icon || "none",
        duration: obj.duration || 3000,
        mask: obj.mask || false,
      });
    } catch (e) {
      // Do something when catch error
    }
  },
  showModal: (obj) => {
    if (!obj) return;
    try {
      wx.showModal({
        title: obj.title || "",
        content: obj.content || "",
        showCancel: obj.showCancel == null ? true : false,
        confirmText: obj.confirmText || "确定",
        success: function (res) {
          if (res.confirm) {
            if (obj.success) obj.success(res);
          }
        },
      });
    } catch (e) {
      // Do something when catch error
    }
  },

  showLoading: (obj) => {
    if (!obj) return;
    try {
      wx.showLoading({
        title: obj.title || "",
        content: obj.mask == null ? false : obj.mask,
        success: function (res) {
          if (res.confirm) {
            if (obj.success) obj.success(res);
          }
        },
        fail: function (res) {
          if (obj.fail) obj.fail(res);
        },
        complete: function (res) {
          if (obj.complete) obj.complete(res);
        },
      });
    } catch (e) {
      // Do something when catch error
    }
  },

  hideLoading: (obj) => {
    if (!obj) {
      try {
        wx.hideLoading();
      } catch (e) {
        // Do something when catch error
      }
    } else {
      try {
        wx.hideLoading({
          success: function (res) {
            if (res.confirm) {
              if (obj.success) obj.success(res);
            }
          },
          fail: function (res) {
            if (obj.fail) obj.fail(res);
          },
          complete: function (res) {
            if (obj.fail) obj.complete(res);
          },
        });
      } catch (e) {
        // Do something when catch error
      }
    }
  },
  promisify: (api) => {
    /*wx api使用转成Promise形式*/
    return (options, ...params) => {
      return new Promise((resolve, reject) => {
        const extras = {
          success: resolve,
          fail: reject,
        };
        api(
          {
            ...options,
            ...extras,
          },
          ...params
        );
      });
    };
  },

  isExist: (obj) => {
    if (
      null === obj ||
      obj === undefined ||
      obj === "undefined" ||
      "null" === obj
    ) {
      return false;
    }
    return true;
  },
  jsonClone: (obj) => {
    try {
      return JSON.parse(JSON.stringify(obj));
    } catch (e) {
      return obj;
    }
  },
  deepClone: (obj) => {
    /*深度克隆对象*/
    if (null === obj || "object" !== typeof obj) {
      return obj;
    }
    let clone;
    if (obj instanceof Date) {
      clone = new Date();
      clone.setTime(obj.getTime());
      return clone;
    }
    if (obj instanceof Array) {
      clone = [];
      let i,
        n = obj.length;
      for (i = 0; i < n; i++) {
        clone[i] = util.deepClone(obj[i]);
      }
      return clone;
    }
    if (obj instanceof Object) {
      clone = {};
      for (let key in obj) {
        if (obj.hasOwnProperty(key)) {
          clone[key] = util.deepClone(obj[key]);
        }
      }
      return clone;
    }
    throw new Error(`Unable to clone obj! Its type isn't supported.`);
  },
  arrayRemove: (val, arr) => {
    /*删除数组内某个元素*/
    if (!arr || !Array.isArray(arr)) {
      return;
    }
    arr.forEach((v, i, a) => {
      if (val === v) {
        a.splice(i, 1);
      }
    });
  },
  cstr: (s) => {
    /*处理null、undefined或NaN字符串*/
    if (s) {
      return s.toString();
    } else {
      return "";
    }
  },
  formatTimeCount: (t) => {
    /*格式化时间戳差*/
    if (t > 0) {
      let h = Math.floor((t / 60 / 60) % 24);
      if (h < 10) {
        h = `0${h}`;
      }
      let m = Math.floor((t / 60) % 60);
      if (m < 10) {
        m = `0${m}`;
      }
      let s = Math.floor(t % 60);
      if (s < 10) {
        s = `0${s}`;
      }
      return `${h}:${m}:${s}`;
    }
    return "";
  },
  formatTimeStr: (t) => {
    if (t) {
      t = parseInt(t);
      let time = new Date(t * 1000);
      let year = time.getFullYear();
      let month = time.getMonth() + 1;
      if (month < 10) {
        month = `0${month}`;
      }
      let date = time.getDate();
      if (date < 10) {
        date = `0${date}`;
      }
      let hour = time.getHours();
      if (hour < 10) {
        hour = `0${hour}`;
      }
      let minute = time.getMinutes();
      if (minute < 10) {
        minute = `0${minute}`;
      }
      let second = time.getSeconds();
      if (second < 10) {
        second = `0${second}`;
      }
      return `${year}-${month}-${date} ${hour}:${minute}:${second}`;
    }
    return "";
  },
  money: (m, c, w) => {
    /*m:金额;c:保留小数位数,只能取值0,1,2;w:1返回整个金额,2返回整数部分,3返回小数部分*/
    if (c !== 0 && c !== 1 && c !== 2) {
      console.log("传入保留小数位数参数错误");
      return "";
    }
    if (w !== 1 && w !== 2 && w !== 3) {
      console.log("传入返回类型参数错误");
      return "";
    }

    if (0 === m) {
      /*由于0=false,需特殊处理*/
      return deal("0", "");
    } else {
      if (!m || isNaN(m)) {
        return "";
      }
      m = m.toString();
      if (-1 === m.indexOf(".")) {
        return deal(m, "");
      } else {
        var s_arr = m.split(".");
        return deal(s_arr[0], s_arr[1]);
      }
    }

    function deal(p, f) {
      /*p为整数部分*/
      if (0 === c) {
        if (1 === w) {
          return p;
        } else if (2 === w) {
          return p;
        } else if (3 === w) {
          return "";
        }
      } else if (1 === c) {
        if (0 === f.length) {
          f = "0";
        } else if (f.length >= 2) {
          f = f.substring(0, 1);
        }
        if (1 === w) {
          return p + "." + f;
        } else if (2 === w) {
          return p;
        } else if (3 === w) {
          return f;
        }
      } else if (2 === c) {
        if (0 === f.length) {
          f = "00";
        } else if (1 === f.length) {
          f = f + "0";
        } else if (f.length >= 3) {
          f = f.substring(0, 2);
        }
        if (1 === w) {
          return p + "." + f;
        } else if (2 === w) {
          return p;
        } else if (3 === w) {
          return f;
        }
      }
    }
  },

  /**
   * 版本号比较
   * https://developers.weixin.qq.com/miniprogram/dev/framework/compatibility.html
   */
  compareVersion: function (v1, v2) {
    v1 = v1.split(".");
    v2 = v2.split(".");
    const len = Math.max(v1.length, v2.length);

    while (v1.length < len) {
      v1.push("0");
    }
    while (v2.length < len) {
      v2.push("0");
    }

    for (let i = 0; i < len; i++) {
      const num1 = parseInt(v1[i]);
      const num2 = parseInt(v2[i]);

      if (num1 > num2) {
        return 1;
      } else if (num1 < num2) {
        return -1;
      }
    }

    return 0;
  },

  isUndef: (val) => {
    return val === undefined || val === null;
  },

  getUrlQuery(url) {
    const result = {};
    if (typeof url !== "string") return result;

    const query = url.split("?")[1];
    if (!query) return result;

    query.split("&").forEach((value) => {
      const v = value.split("=");
      result[v[0]] = v[1];
    });
    return result;
  },

  /**
   * 函数防抖(只执行最后一次点击)
   */
  debounce: (fn, delay) => {
    let timer = null;
    delay = delay || 300;
    return (...args) => {
      clearTimeout(timer);
      timer = setTimeout(() => {
        fn.apply(this, args);
      }, delay);
    };
  },
  /**
   * 函数节流
   */
  throttle: (fn, delay) => {
    let last = Date.now();
    delay = delay || 300;
    return (...args) => {
      let now = Date.now();
      if (now - last >= delay) {
        last = now;
        fn.apply(this, args);
      }
    };
  },
  getDateTimeStamp(dateStr) {
    return Date.parse(dateStr.replace(/-/gi, "/"));
  },
  getDateDiff(dateTimeStamp) {
    // dateTimeStamp为时间戳
    var minute = 1000 * 60;
    var hour = minute * 60;
    var day = hour * 24;
    var month = day * 30;
    var now = new Date().getTime();
    var diffValue = now - dateTimeStamp;
    if (diffValue < 0) {
      return "刚刚发表";
    }
    var monthC = diffValue / month;
    var weekC = diffValue / (7 * day);
    var dayC = diffValue / day;
    var hourC = diffValue / hour;
    var minC = diffValue / minute;
    var result;
    if (monthC >= 1) {
      result = parseInt(monthC) + "个月前";
    } else if (weekC >= 1) {
      result = parseInt(weekC) + "周前";
    } else if (dayC >= 1) {
      result = parseInt(dayC) + "天前";
    } else if (hourC >= 1) {
      result = parseInt(hourC) + "个小时前";
    } else if (minC >= 1) {
      result = parseInt(minC) + "分钟前";
    } else {
      result = "刚刚发表";
    }
    return result;
  },
  validator: {
    /*校验字段合法性rule*/
    checkMobile: (s) => {
      /*校验手机号格式是否正确*/
      if (s) {
        s = s.toString().trim();
        var rule = /^\d{3,20}$/;
        return rule.test(s);
      }
      return false;
    },
    checkEmail: (s) => {
      /*校验邮箱格式是否正确*/
      if (s) {
        s = s.toString().trim();
        var rule = /^(([^()[\]\\.,;:\s@\"]+(\.[^()[\]\\.,;:\s@\"]+)*)|(\".+\"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/g;
        return rule.test(s);
      }
      return false;
    },
    checkPwd: (s) => {
      /*校验登录密码格式是否正确*/
      if (s) {
        s = s.toString().trim();
        var rule = /^(?=.*[a-zA-Z]+)(?=.*[0-9]+)[a-zA-Z0-9]{8,16}$/;
        return rule.test(s);
      }
      return false;
    },
    checkCode: (s) => {
      /*校验短信或邮箱验证码格式是否正确*/
      if (s) {
        s = s.toString().trim();
        var rule = /^\d{6}$/;
        return rule.test(s);
      }
      return false;
    },
    checkImgCode: (s) => {
      /*校验图片验证码格式是否正确*/
      if (s) {
        s = s.toString().trim();
        var rule = /^[a-zA-Z]{4}$/;
        return rule.test(s);
      }
      return false;
    },
    checkNickname: (s) => {
      /*校验昵称格式是否正确*/
      if (s) {
        s = s.toString().trim();
        var rule = /^[A-Za-z0-9\u4e00-\u9fa5]{2,20}$/;
        return rule.test(s);
      }
      return false;
    },
  },
};
module.exports = util;
